import math
from scipy import constants as const

# Konstanten aus scipy.constants
c   = const.c          # Lichtgeschwindigkeit in m/s
hbar= const.hbar       # ℏ in J·s
e   = const.e          # Elementarladung in Coulomb
k_e = 1/(4*math.pi*const.epsilon_0)  # Coulomb-Konstante in N·m²/C²

def gamma_quantum_time(E_joule, r_meter):
    """Berechnet γ = c^2 ℏ^2 / (k e^2 E r)."""
    return c**2 * hbar**2 / (k_e * e**2 * E_joule * r_meter)

# Beispielszenarien (E in eV, r in m):
scenarios = [
    ("Wasserstoff Grundzustand",    13.6,        0.529e-10),  # E=13,6 eV, r = 0,529 Å
    ("Wasserstoff angeregt (n=2)",   3.4,        2.116e-10),  # E≈3,4 eV, r≈2,116 Å (n=2)
    ("Chemische Bindung (~C–H)",     4.5,        1.10e-10),   # E≈4-5 eV, r≈1,1 Å
    ("Thermische Energie (300 K)",   0.025,      5.0e-10),    # E≈0,025 eV, r≈5 Å (Raumtemperatur, Atomgitter)
    ("Kernbindung (typisch)",       8.0e6,      5.0e-15),    # E≈8 MeV, r≈5 fm (Bindung in mittelschwerem Kern)
    ("Starke Kernkraft (extrem)",   2.0e8,      1.0e-15),    # E≈200 MeV, r=1 fm (starke Bindung im Kern)
    ("H–Anti-H Annihilation",       1.88e9,     0.529e-10),  # E≈1,88 GeV, r=0,529 Å (H mit Anti-H Abstand ~ Bohr)
    ("Kritischer Punkt (γ=1)",      5.11e5,     0.529e-10)   # E=511 keV, r=0,529 Å (Elektron-Ruheenergie)
]

print(f"{'Szenario':30} | {'Energie E':>15} | {'Abstand r':>12} | γ (berechnet)")
print("-"*75)
for name, E_eV, r in scenarios:
    E_J = E_eV * const.e  # eV -> Joule
    gamma_val = gamma_quantum_time(E_J, r)
    print(f"{name:30} | {E_eV:9.2e} eV | {r:8.2e} m | {gamma_val:9.3e}")
